========================
Thread-Local Storage API 
========================

:Author: Etienne Robillard <tkadm30@yandex.com>
:Version: 0.6.2
:Last modified: 2017-01-23

The ``notmm.datastore.threadlocal`` module provides a simple
thread-local based storage backend. 

